# ListVMMachineTypesRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cpu_model** | **str** |  | [optional] 
**data_center_id** | **str** |  | [optional] 
**gpu** | **int** |  | [optional] 
**gpu_model** | **str** |  | [optional] 
**memory_gib** | **int** |  | 
**order_by** | **str** |  | [optional] 
**page_number** | **int** |  | [optional] 
**page_size** | **int** |  | [optional] 
**public_ipv4** | **bool** |  | [optional] 
**region_id** | **str** |  | [optional] 
**storage_gib** | **int** |  | [optional] 
**vcpu** | **int** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


